==> django-froala-editor-1.2.4.tar.gz: django-froala-editor-1.2.4/froala_editor/static/froala_editor/js/langs/cs.js <==
/*!
 * froala_editor v1.2.4 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Czech
 */

$.Editable.LANGS['cs'] = {
  translation: {
    "Bold": "Tu\u010dn\u00e9",
    "Italic": "Kurz\u00edva",
    "Underline": "Podtr\u017een\u00e9",
    "Strikethrough": "P\u0159e\u0161rktnut\u00e9",
    "Font Size": "Velikost p\u00edsma",
    "Color": "Barva",
    "Background": "Pozad\u00ed",
    "Text": "P\u00edsma",
    "Format Block": "Form\u00e1ty",
    "Normal": "Norm\u00e1ln\u00ed",
    "Paragraph": "Odstavec",
    "Code": "K\u00f3d - Code",
    "Quote": "Citace",
    "Heading 1": "Nadpis 1",
    "Heading 2": "Nadpis 2",
    "Heading 3": "Nadpis 3",
    "Heading 4": "Nadpis 4",
    "Heading 5": "Nadpis 5",
    "Heading 6": "Nadpis 6",
    "Block Style": "Block styl",
    "Alignment": "Zarovn\u00e1n\u00ed",
    "Align Left": "Zarovnat vlevo",
    "Align Center": "Zarovnat na st\u0159ed",
    "Align Right": "Zarovnat vpravo",
    "Justify": "Zarovnat do bloku",
    "Numbered List": "\u010c\u00edslov\u00e1n\u00ed",
    "Bulleted List": "Odr\u00e1\u017eky",
    "Indent Less": "Zmen\u0161it odsazen\u00ed",
    "Indent More": "Zv\u011bt\u0161it odsazen\u00ed",
    "Select All": "Vybrat v\u0161e",
    "Insert Link": "Vlo\u017eit odkaz",
    "Insert Image": "Vlo\u017eit obr\u00e1zek",
    "Insert Video": "Vlo\u017eit video",
    "Undo": "Zp\u011bt",
    "Redo": "Znovu",
    "Show HTML": "Zobrazit HTML",
    "Float Left": "Vlevo",
    "Float None": "\u017d\u00e1dn\u00e9",
    "Float Right": "Vpravo",
    "Replace Image": "Nahra\u010fte obr\u00e1zek",
    "Remove Image": "Odstranit obr\u00e1zek",
    "Title": "Titulek",
    "Drop image": "Shodit obr\u00e1zek",
    "or click": "nebo klepn\u011bte na tla\u010d\u00edtko",
    "or": "nebo",
    "Enter URL": "Zadejte adresu URL",
    "Please wait!": "\u010cekejte, pros\u00edm!",
    "Are you sure? Image will be deleted.": "Jsi si jist\u00fd? Obr\u00e1zek bude smaz\u00e1n.",
    "UNLINK": "Odstranit odkaz",
    "Open in new tab": "Otev\u0159\u00edt v nov\u00e9 z\u00e1lo\u017ece",
    "Type something": "Napi\u0161te n\u011bco",
    "Cancel": "Zru\u0161it",
    "OK": "OK",
    "Manage images": "Spr\u00e1va obr\u00e1zk\u016f",
    "Delete": "Vymazat",
    "Font Family": "Typ p\u00edsma",
    "Insert Horizontal Line": "Vlo\u017eit vodorovnou \u010d\u00e1ru",
    "Table": "Tabulka",
    "Insert table": "Vlo\u017eit tabulku",
    "Cell": "Bu\u0148ka",
    "Row": "\u0158\u00e1dek",
    "Column": "Sloupec",
    "Delete table": "Smazat tabulku",
    "Insert cell before": "Vlo\u017eit bu\u0148ka vlevo",
    "Insert cell after": "Vlo\u017eit bu\u0148ka vpravo",
    "Delete cell": "Smazat bu\u0148ky",
    "Merge cells": "Slou\u010dit bu\u0148ky",
    "Horizontal split": "Horizont\u00e1ln\u00ed rozd\u011blen\u00ed",
    "Vertical split": "Vertik\u00e1ln\u00ed rozd\u011blen\u00ed",
    "Insert row above": "Vlo\u017eit \u0159\u00e1dek nad",
    "Insert row below": "Vlo\u017eit \u0159\u00e1dek pod",
    "Delete row": "Smazat \u0159\u00e1dek",
    "Insert column before": "Vlo\u017eit sloupec vlevo",
    "Insert column after": "Vlo\u017eit sloupec vpravo",
    "Delete column": "Smazat sloupec",
    "Uploading image": "Nahr\u00e1v\u00e1n\u00ed obrazu",
    "Upload File": "Nahr\u00e1t soubor",
    "Drop File": "Drop soubor",
    "Clear formatting": "Vymazat form\u00e1tov\u00e1n\u00ed"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.5.tar.gz: django-froala-editor-1.2.5/froala_editor/static/froala_editor/js/langs/cs.js <==
/*!
 * froala_editor v1.2.5 (http://editor.froala.com)
 * License http://editor.froala.com/license
 * Copyright 2014-2015 Froala Labs
 */

/**
 * Czech
 */

$.Editable.LANGS['cs'] = {
  translation: {
    "Bold": "Tu\u010dn\u00e9",
    "Italic": "Kurz\u00edva",
    "Underline": "Podtr\u017een\u00e9",
    "Strikethrough": "P\u0159e\u0161krtnut\u00e9",
    "Font Size": "Velikost p\u00edsma",
    "Color": "Barva",
    "Background": "Pozad\u00ed",
    "Text": "P\u00edsmo",
    "Format Block": "Form\u00e1ty",
    "Normal": "Norm\u00e1ln\u00ed",
    "Paragraph": "Odstavec",
    "Code": "K\u00f3d",
    "Quote": "Citace",
    "Heading 1": "Nadpis 1",
    "Heading 2": "Nadpis 2",
    "Heading 3": "Nadpis 3",
    "Heading 4": "Nadpis 4",
    "Heading 5": "Nadpis 5",
    "Heading 6": "Nadpis 6",
    "Block Style": "Blok styl",
    "Alignment": "Zarovn\u00e1n\u00ed",
    "Align Left": "Zarovnat vlevo",
    "Align Center": "Zarovnat na st\u0159ed",
    "Align Right": "Zarovnat vpravo",
    "Justify": "Zarovnat do bloku",
    "Numbered List": "\u010c\u00edslov\u00e1n\u00ed",
    "Bulleted List": "Odr\u00e1\u017eky",
    "Indent Less": "Zmen\u0161it odsazen\u00ed",
    "Indent More": "Zv\u011bt\u0161it odsazen\u00ed",
    "Select All": "Vybrat v\u0161e",
    "Insert Link": "Vlo\u017eit odkaz",
    "Insert Image": "Vlo\u017eit obr\u00e1zek",
    "Insert Video": "Vlo\u017eit video",
    "Undo": "Zp\u011bt",
    "Redo": "Znovu",
    "Show HTML": "Zobrazit HTML",
    "Float Left": "Vlevo",
    "Float None": "\u017d\u00e1dn\u00e9",
    "Float Right": "Vpravo",
    "Replace Image": "Nahradit obr\u00e1zek",
    "Remove Image": "Odstranit obr\u00e1zek",
    "Title": "Titulek",
    "Drop image": "P\u0159et\u00e1hn\u011bte sem obr\u00e1zek",
    "or click": "nebo zde klepn\u011bte",
    "or": "nebo",
    "Enter URL": "Zadejte adresu URL",
    "Please wait!": "\u010cekejte, pros\u00edm!",
    "Are you sure? Image will be deleted.": "Ur\u010dit\u011b? Obr\u00e1zek bude smaz\u00e1n.",
    "UNLINK": "Odstranit odkaz",
    "Open in new tab": "Otev\u0159\u00edt v nov\u00e9 z\u00e1lo\u017ece",
    "Type something": "Napi\u0161te n\u011bco",
    "Cancel": "Zru\u0161it",
    "OK": "OK",
    "Manage images": "Spr\u00e1va obr\u00e1zk\u016f",
    "Delete": "Vymazat",
    "Font Family": "Typ p\u00edsma",
    "Insert Horizontal Line": "Vlo\u017eit vodorovnou \u010d\u00e1ru",
    "Table": "Tabulka",
    "Insert table": "Vlo\u017eit tabulku",
    "Cell": "Bu\u0148ka",
    "Row": "\u0158\u00e1dek",
    "Column": "Sloupec",
    "Delete table": "Smazat tabulku",
    "Insert cell before": "Vlo\u017eit bu\u0148ku vlevo",
    "Insert cell after": "Vlo\u017eit bu\u0148ku vpravo",
    "Delete cell": "Smazat bu\u0148ku",
    "Merge cells": "Slou\u010dit bu\u0148ky",
    "Horizontal split": "Horizont\u00e1ln\u00ed rozd\u011blen\u00ed",
    "Vertical split": "Vertik\u00e1ln\u00ed rozd\u011blen\u00ed",
    "Insert row above": "Vlo\u017eit \u0159\u00e1dek nad",
    "Insert row below": "Vlo\u017eit \u0159\u00e1dek pod",
    "Delete row": "Smazat \u0159\u00e1dek",
    "Insert column before": "Vlo\u017eit sloupec vlevo",
    "Insert column after": "Vlo\u017eit sloupec vpravo",
    "Delete column": "Smazat sloupec",
    "Uploading image": "Nahr\u00e1v\u00e1n\u00ed obr\u00e1zku",
    "Upload File": "Nahr\u00e1t soubor",
    "Drop File": "P\u0159et\u00e1hn\u011bte sem soubor",
    "Clear formatting": "Vymazat form\u00e1tov\u00e1n\u00ed"
  },
  direction: "ltr"
};
